@@ -1,9 +1,10 @@
+
 /*!
  * \file   bindings/python/mfront/AbstractBehaviourDSL.cxx
  * \brief
  * \author Thomas Helfer
  * \date   04/05/2016
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -13,19 +14,19 @@
 
 #include <set>
 #include <memory>
-#include "TFEL/Python/SharedPtr.hxx"
-#include <boost/python.hpp>
+#include <pybind11/pybind11.h>
+#include <pybind11/stl.h>
 #include "MFront/BehaviourDescription.hxx"
 #include "MFront/AbstractBehaviourDSL.hxx"
 
-void declareAbstractBehaviourDSL();
-void declareAbstractBehaviourDSL() {
-  using namespace boost::python;
+void declareAbstractBehaviourDSL(pybind11::module_&);
+
+void declareAbstractBehaviourDSL(pybind11::module_& m) {
   using namespace mfront;
-  class_<AbstractBehaviourDSL, std::shared_ptr<AbstractBehaviourDSL>,
-         bases<AbstractDSL>, boost::noncopyable>("AbstractBehaviourDSL",
-                                                 no_init)
+  pybind11::class_<AbstractBehaviourDSL, AbstractDSL,
+                   std::shared_ptr<AbstractBehaviourDSL>>(
+      m, "AbstractBehaviourDSL")
       .def("getBehaviourDescription",
            &AbstractBehaviourDSL::getBehaviourDescription,
-           return_internal_reference<>());
+           pybind11::return_value_policy::reference);
 }
