@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   12 mai 2016
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -11,19 +11,21 @@
  * project under specific licensing conditions.
  */
 
-#include <boost/python.hpp>
+#include <pybind11/pybind11.h>
+#include <pybind11/stl.h>
 #include "MTest/PipeMesh.hxx"
 
-void declarePipeMesh();
+void declarePipeMesh(pybind11::module_&);
 
-void declarePipeMesh() {
-  boost::python::enum_<mtest::PipeMesh::ElementType>("PipeMeshElementType")
+void declarePipeMesh(pybind11::module_& m) {
+  pybind11::enum_<mtest::PipeMesh::ElementType>(m, "PipeMeshElementType")
       .value("DEFAULT", mtest::PipeMesh::DEFAULT)
       .value("LINEAR", mtest::PipeMesh::LINEAR)
       .value("QUADRATIC", mtest::PipeMesh::QUADRATIC)
       .value("CUBIC", mtest::PipeMesh::CUBIC);
 
-  boost::python::class_<mtest::PipeMesh, boost::noncopyable>("PipeMesh")
+  pybind11::class_<mtest::PipeMesh>(m, "PipeMesh")
+      .def(pybind11::init<>())
       .def_readonly("inner_radius", &mtest::PipeMesh::inner_radius)
       .def_readonly("outer_radius", &mtest::PipeMesh::outer_radius)
       .def_readonly("number_of_elements", &mtest::PipeMesh::number_of_elements)
