@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   17 mars 2016
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -13,7 +13,7 @@
 
 #include <fstream>
 #include "TFEL/Raise.hxx"
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/MFrontUtilities.hxx"
 #include "MFront/MFrontLogStream.hxx"
 #include "MFront/FileDescription.hxx"
 #include "MFront/AbaqusInterfaceBase.hxx"
@@ -604,10 +604,10 @@ namespace mfront {
           };
           for (auto pm = mps.first.begin(); pm != mps.first.end();) {
             if (pm->arraySize == 1u) {
-              write(pm->name);
+              write(pm->getExternalName());
             } else {
               for (unsigned short a = 0; a != pm->arraySize;) {
-                write(pm->name + "_" + std::to_string(a));
+                write(pm->getExternalName() + "_" + std::to_string(a));
                 if (++a != pm->arraySize) {
                   out << ", ";
                 }
