@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   17 Jan 2007
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -22,13 +22,14 @@
 #include "TFEL/Utilities/StringAlgorithms.hxx"
 #include "TFEL/System/System.hxx"
 
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/MFrontWarningMode.hxx"
 #include "MFront/MFrontLock.hxx"
 #include "MFront/MFrontUtilities.hxx"
 #include "MFront/MFrontLogStream.hxx"
 #include "MFront/MFrontDebugMode.hxx"
 #include "MFront/FileDescription.hxx"
 #include "MFront/TargetsDescription.hxx"
+#include "MFront/VariableDescription.hxx"
 #include "MFront/Ansys/AnsysOrthotropicBehaviour.hxx"
 #include "MFront/AnsysSymbolsGenerator.hxx"
 #include "MFront/AnsysInterface.hxx"
@@ -677,6 +678,17 @@ namespace mfront {
     auto throw_if = [](const bool b, const std::string& m) {
       tfel::raise_if(b, "AnsysInterface::treatKeyword: " + m);
     };
+    auto check_interface_restriction = [this, &i, &key] {
+      if (i.empty()) {
+        reportWarning("keyword '" + key +
+                      "' is used without being restricted to the " +
+                      this->getName() +
+                      " interface, which could be a portability "
+                      "issue. Please add [" +
+                      this->getName() + "] after the keyword (i.e. replace '" +
+                      key + "' by '" + key + "[" + this->getName() + "]')");
+      }
+    };
     if (!i.empty()) {
       if (std::find(i.begin(), i.end(), this->getName()) != i.end()) {
         auto keys = {"@AnsysFiniteStrainStrategy",
@@ -684,7 +696,8 @@ namespace mfront {
                      "@AnsysCompareToNumericalTangentOperator",
                      "@AnsysTangentOperatorComparisonCriterium",
                      "@AnsysTangentOperatorComparisonCriterion",
-                     "@AnsysStrainPerturbationValue"};
+                     "@AnsysStrainPerturbationValue",
+                     "@GenerateMTestFileOnFailure"};
         throw_if(std::find(keys.begin(), keys.end(), key) == keys.end(),
                  "unsupported key '" + key + "'");
       } else {
@@ -692,6 +705,7 @@ namespace mfront {
       }
     }
     if (key == "@AnsysFiniteStrainStrategy") {
+      check_interface_restriction();
       throw_if(bd.hasAttribute(AnsysInterface::finiteStrainStrategy),
                "a finite strain strategy has already been defined");
       throw_if(current == end, "unexpected end of file");
@@ -709,16 +723,22 @@ namespace mfront {
       bd.setAttribute(AnsysInterface::finiteStrainStrategy, fs, false);
       return {true, current};
     }
-    if (key == "@AnsysGenerateMTestFileOnFailure") {
+    if ((key == "@AnsysGenerateMTestFileOnFailure") ||
+        (key == "@GenerateMTestFileOnFailure")) {
+      if (key == "@AnsysGenerateMTestFileOnFailure") {
+        check_interface_restriction();
+      }
       this->setGenerateMTestFileOnFailureAttribute(
           bd, this->readBooleanValue(key, current, end));
       return {true, current};
     } else if (key == "@AnsysCompareToNumericalTangentOperator") {
+      check_interface_restriction();
       this->compareToNumericalTangentOperator =
           this->readBooleanValue(key, current, end);
       return make_pair(true, current);
     } else if ((key == "@AnsysTangentOperatorComparisonCriterium") ||
                (key == "@AnsysTangentOperatorComparisonCriterion")) {
+      check_interface_restriction();
       throw_if(
           !this->compareToNumericalTangentOperator,
           "comparison to tangent operator is not enabled at this stage.\n"
@@ -733,6 +753,7 @@ namespace mfront {
       ++(current);
       return {true, current};
     } else if (key == "@AnsysStrainPerturbationValue") {
+      check_interface_restriction();
       throw_if(!this->compareToNumericalTangentOperator,
                "time stepping is not enabled at this stage.\n"
                "Use the @AnsysUseTimeSubStepping directive before "
@@ -1013,15 +1034,47 @@ namespace mfront {
               << "          << \"invalid number of material properties\\n\";\n"
               << "*keycut = 1;\n"
               << "return;\n"
-              << "}\n"
-              << "ansys::AnsysRotation2D<ansys::AnsysReal> R(PROPS+" +
-                     smpoffset + ");\n"
-              << "ansys::AnsysReal e[4u];\n"
-              << "ansys::AnsysReal de[4u];\n"
-              << "ansys::AnsysReal sm[4u];\n"
-              << "R.rotateStrainsForward(STRAN,e);\n"
-              << "R.rotateStrainsForward(DSTRAN,de);\n"
-              << "R.rotateStressesForward(STRESS,sm);\n";
+              << "}\n";
+          if (h == ModellingHypothesis::PLANESTRESS) {
+            out << "ansys::AnsysReal STRAN_tmp[4u];\n"
+                << "ansys::AnsysReal DSTRAN_tmp[4u];\n"
+                << "ansys::AnsysReal STRESS_tmp[4u];\n"
+                << "STRAN_tmp[0] = STRAN[0];\n"
+                << "STRAN_tmp[1] = STRAN[1];\n"
+                << "STRAN_tmp[2] = ansys::AnsysReal{};\n"
+                << "STRAN_tmp[3] = STRAN[2];\n"
+                << "DSTRAN_tmp[0] = DSTRAN[0];\n"
+                << "DSTRAN_tmp[1] = DSTRAN[1];\n"
+                << "DSTRAN_tmp[2] = ansys::AnsysReal{};\n"
+                << "DSTRAN_tmp[3] = DSTRAN[2];\n"
+                << "STRESS_tmp[0] = STRESS[0];\n"
+                << "STRESS_tmp[1] = STRESS[1];\n"
+                << "STRESS_tmp[2] = ansys::AnsysReal{};\n"
+                << "STRESS_tmp[3] = STRESS[2];\n"
+                << "ansys::AnsysRotation2D<ansys::AnsysReal> R(PROPS+" +
+                       smpoffset + ");\n"
+                << "ansys::AnsysReal e[4u];\n"
+                << "ansys::AnsysReal de[4u];\n"
+                << "ansys::AnsysReal sm[4u];\n"
+                << "R.rotateStrainsForward(STRAN_tmp,e);\n"
+                << "R.rotateStrainsForward(DSTRAN_tmp,de);\n"
+                << "R.rotateStressesForward(STRESS_tmp,sm);\n"
+                << "e[2] = e[3];\n"
+                << "e[3] = ansys::AnsysReal{};\n"
+                << "de[2] = de[3];\n"
+                << "de[3] = ansys::AnsysReal{};\n"
+                << "sm[2] = sm[3];\n"
+                << "sm[3] = ansys::AnsysReal{};\n";
+          } else {
+            out << "ansys::AnsysRotation2D<ansys::AnsysReal> R(PROPS+" +
+                       smpoffset + ");\n"
+                << "ansys::AnsysReal e[4u];\n"
+                << "ansys::AnsysReal de[4u];\n"
+                << "ansys::AnsysReal sm[4u];\n"
+                << "R.rotateStrainsForward(STRAN,e);\n"
+                << "R.rotateStrainsForward(DSTRAN,de);\n"
+                << "R.rotateStressesForward(STRESS,sm);\n";
+          }
         } else if (h == ModellingHypothesis::TRIDIMENSIONAL) {
           out << "if(*NPROPS<static_cast<ansys::AnsysInt>(" + smpoffset +
                      "+6u)){\n"
@@ -1036,9 +1089,9 @@ namespace mfront {
               << "ansys::AnsysReal e[6u];\n"
               << "ansys::AnsysReal de[6u];\n"
               << "ansys::AnsysReal sm[6u];\n"
-              << "R.rotateStrainsForward(STRAN,e);\n"
-              << "R.rotateStrainsForward(DSTRAN,de);\n"
-              << "R.rotateStressesForward(STRESS,sm);\n";
+              << "R.rotateStrainsForward(STRAN, e);\n"
+              << "R.rotateStrainsForward(DSTRAN, de);\n"
+              << "R.rotateStressesForward(STRESS, sm);\n";
         } else {
           throw_if(true, "unsupported hypothesis");
         }
@@ -1126,7 +1179,12 @@ namespace mfront {
             << "                           DDSDDE[1],DDSDDE[4],0,DDSDDE[7],\n"
             << "                           0,0,0,0,\n"
             << "                           DDSDDE[2],DDSDDE[5],0,DDSDDE[8]};\n"
-            << "R.rotateStressesBackward(sm,STRESS);\n"
+            << "sm[3] = sm[2];\n"
+            << "sm[2] = ansys::AnsysReal{};\n"
+            << "R.rotateStressesBackward(sm, STRESS_tmp);\n"
+            << "STRESS[0] = STRESS_tmp[0];\n"
+            << "STRESS[1] = STRESS_tmp[1];\n"
+            << "STRESS[2] = STRESS_tmp[3];\n"
             << "R.rotateTangentOperatorBackward(D);\n"
             << "DDSDDE[0]=D[0];\n"
             << "DDSDDE[1]=D[4];\n"
@@ -1703,10 +1761,6 @@ namespace mfront {
     const auto name = bd.getLibrary() + bd.getClassName();
     const auto tfel_config = tfel::getTFELConfigExecutableName();
     auto& l = d.getLibrary(lib);
-    insert_if(l.cppflags,
-              "$(shell " + tfel_config + " --cppflags --compiler-flags)");
-    insert_if(l.include_directories,
-              "$(shell " + tfel_config + " --include-path)");
     insert_if(l.sources, "ansys" + name + ".cxx");
     d.headers.push_back("MFront/Ansys/ansys" + name + ".hxx");
     insert_if(l.link_directories,
