@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   19/07/2018
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -13,7 +13,7 @@
 
 #include <ostream>
 #include "TFEL/Raise.hxx"
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/BehaviourDescription.hxx"
 #include "MFront/BehaviourInterfaceBase.hxx"
 #include "MFront/AnsysInterface.hxx"
