@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   17 Jan 2007
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -21,12 +21,13 @@
 #include "TFEL/Utilities/StringAlgorithms.hxx"
 #include "TFEL/System/System.hxx"
 
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/MFrontWarningMode.hxx"
 #include "MFront/MFrontUtilities.hxx"
 #include "MFront/MFrontLogStream.hxx"
 #include "MFront/MFrontDebugMode.hxx"
 #include "MFront/FileDescription.hxx"
 #include "MFront/TargetsDescription.hxx"
+#include "MFront/VariableDescription.hxx"
 #include "MFront/AsterSymbolsGenerator.hxx"
 #include "MFront/AsterInterface.hxx"
 
@@ -82,9 +83,21 @@ namespace mfront {
     auto throw_if = [](const bool b, const std::string& m) {
       tfel::raise_if(b, "AsterInterface::treatKeyword : " + m);
     };
+    auto check_interface_restriction = [this, &i, &key] {
+      if (i.empty()) {
+        reportWarning("keyword '" + key +
+                      "' is used without being restricted to the " +
+                      this->getName() +
+                      " interface, which could be a portability "
+                      "issue. Please add [" +
+                      this->getName() + "] after the keyword (i.e. replace '" +
+                      key + "' by '" + key + "[" + this->getName() + "]')");
+      }
+    };
     if (!i.empty()) {
       if (std::find(i.begin(), i.end(), this->getName()) != i.end()) {
         throw_if((key != "@AsterGenerateMTestFileOnFailure") &&
+                     (key != "@GenerateMTestFileOnFailure") &&
                      (key != "@AsterCompareToNumericalTangentOperator") &&
                      (key != "@AsterTangentOperatorComparisonCriterium") &&
                      (key != "@AsterTangentOperatorComparisonCriterion") &&
@@ -97,18 +110,24 @@ namespace mfront {
         return {false, current};
       }
     }
-    if (key == "@AsterGenerateMTestFileOnFailure") {
+    if ((key == "@AsterGenerateMTestFileOnFailure") ||
+        (key == "@GenerateMTestFileOnFailure")) {
+      if (key == "@AsterGenerateMTestFileOnFailure") {
+        check_interface_restriction();
+      }
       this->setGenerateMTestFileOnFailureAttribute(
           bd, this->readBooleanValue(key, current, end));
       return {true, current};
     }
     if (key == "@AsterCompareToNumericalTangentOperator") {
+      check_interface_restriction();
       this->compareToNumericalTangentOperator =
           this->readBooleanValue(key, current, end);
       return make_pair(true, current);
     }
     if ((key == "@AsterTangentOperatorComparisonCriterium") ||
         (key == "@AsterTangentOperatorComparisonCriterion")) {
+      check_interface_restriction();
       throw_if(
           !this->compareToNumericalTangentOperator,
           "comparison to tangent operator is not enabled at this stage.\n"
@@ -124,6 +143,7 @@ namespace mfront {
       return {true, current};
     }
     if (key == "@AsterStrainPerturbationValue") {
+      check_interface_restriction();
       throw_if(!this->compareToNumericalTangentOperator,
                "time stepping is not enabled at this stage.\n"
                "Use the @AsterUseTimeSubStepping directive before "
@@ -137,15 +157,18 @@ namespace mfront {
       return {true, current};
     }
     if (key == "@AsterSaveTangentOperator") {
+      check_interface_restriction();
       bd.setAttribute(AsterInterface::saveTangentOperator,
                       this->readBooleanValue(key, current, end), false);
       return {true, current};
     }
     if (key == "@AsterErrorReport") {
+      check_interface_restriction();
       this->errorReport = this->readBooleanValue(key, current, end);
       return {true, current};
     }
     if (key == "@AsterFiniteStrainFormulation") {
+      check_interface_restriction();
       throw_if(bd.getBehaviourType() !=
                    BehaviourDescription::STANDARDFINITESTRAINBEHAVIOUR,
                "the '@AsterFiniteStrainFormulation' is only valid "
@@ -750,8 +773,6 @@ namespace mfront {
     const auto name = bd.getLibrary() + bd.getClassName();
     const auto tfel_config = tfel::getTFELConfigExecutableName();
     auto& l = d.getLibrary(lib);
-    insert_if(l.cppflags,
-              "$(shell " + tfel_config + " --cppflags --compiler-flags)");
 #if ASTER_ARCH == 64
     insert_if(l.cppflags, "-DASTER_ARCH=64");
 #elif ASTER_ARCH == 32
@@ -759,8 +780,6 @@ namespace mfront {
 #else
 #error "AsterInterface::getGlobalIncludes : unsuported architecture"
 #endif
-    insert_if(l.include_directories,
-              "$(shell " + tfel_config + " --include-path)");
     insert_if(l.sources, "aster" + name + ".cxx");
     d.headers.push_back("MFront/Aster/aster" + name + ".hxx");
     insert_if(l.link_libraries, tfel::getLibraryInstallName("AsterInterface"));
