@@ -4,7 +4,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   18/01/2007
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -24,16 +24,17 @@
 #include "TFEL/Utilities/CxxTokenizer.hxx"
 #include "TFEL/Utilities/StringAlgorithms.hxx"
 #include "MFront/MFrontUtilities.hxx"
-#include "MFront/DSLUtilities.hxx"
 #include "MFront/PerformanceProfiling.hxx"
 #include "MFront/MFrontLogStream.hxx"
 #include "MFront/ModelDescription.hxx"
+#include "MFront/BehaviourVariableDescription.hxx"
 #include "MFront/BehaviourData.hxx"
 
 namespace mfront {
 
   const char* const BehaviourData::UserDefinedInitializeCodeBlock =
       "UserDefinedInitializeCodeBlock";
+  const char* const BehaviourData::BeforeFlowRule = "BeforeFlowRule";
   const char* const BehaviourData::FlowRule = "FlowRule";
   const char* const BehaviourData::BeforeInitializeLocalVariables =
       "BeforeInitializeLocalVariables";
@@ -215,6 +216,8 @@ namespace mfront {
     this->cblock.staticMembers.insert(c.staticMembers.begin(),
                                       c.staticMembers.end());
     this->cblock.members.insert(c.members.begin(), c.members.end());
+    this->cblock.block_variables.insert(c.block_variables.begin(),
+                                        c.block_variables.end());
     for (const auto& a : c.attributes) {
       if (this->cblock.attributes.count(a.first) != 0) {
         auto& ca = this->cblock.attributes[a.first];
@@ -312,7 +315,7 @@ namespace mfront {
   void BehaviourData::CodeBlocksAggregator::check() const {
     tfel::raise_if(!this->is_mutable,
                    "BehaviourData::CodeBlocksAggregator::set: "
-                   "can't modifiy a code block");
+                   "can't modify a code block");
   }  // end of CodeBlocksAggregator::check
 
   const CodeBlock& BehaviourData::CodeBlocksAggregator::get() const {
@@ -324,8 +327,7 @@ namespace mfront {
 
   BehaviourData::BehaviourData() {
     this->registerMemberName("dt");
-    // symbolic value
-    this->reserveName("\u0394t");
+    this->registerMemberName("\u0394t");
   }  // end of BehaviourData
 
   BehaviourData::BehaviourData(const BehaviourData&) = default;
@@ -469,6 +471,11 @@ namespace mfront {
     return this->getParameters().getVariableByExternalName(v);
   }  // end of getParameterDescriptionByExternalName
 
+  const StaticVariableDescription& BehaviourData::getStaticVariableDescription(
+      const std::string& n) const {
+    return this->getStaticVariables().get(n);
+  }  // end of getStaticVariableDescription
+
   void BehaviourData::addMaterialProperty(const VariableDescription& v,
                                           const RegistrationStatus s) {
     this->addVariable(this->materialProperties, v, s, false);
@@ -518,6 +525,11 @@ namespace mfront {
     } else {
       this->addVariable(this->persistentVariables, v, ALREADYREGISTRED, false);
     }
+    if (v.getAttribute<bool>("ComputedByExternalModel", false)) {
+      const auto dv =
+          VariableDescription{v.type, "d" + v.name, v.arraySize, v.lineNumber};
+      this->addLocalVariable(dv, s);
+    }
   }  // end of addAuxiliaryStateVariable
 
   void BehaviourData::addPostProcessingVariable(const VariableDescription& v) {
@@ -554,6 +566,64 @@ namespace mfront {
     this->addVariable(this->externalStateVariables, v, s, true);
   }  // end of addExternalStateVariable
 
+  void BehaviourData::addBehaviourVariable(
+      const BehaviourVariableDescription& v) {
+    if ((this->hasAttribute(BehaviourData::allowsNewUserDefinedVariables)) &&
+        (!this->getAttribute<bool>(
+            BehaviourData::allowsNewUserDefinedVariables))) {
+      const auto cbn = this->getCodeBlockNames();
+      tfel::raise_if(
+          cbn.empty(),
+          "BehaviourData::addBehaviourVariable: can't add variable '" + v.name +
+              "' of type '" + v.behaviour.getClassName() +
+              "', no more variable can be defined. This may mean that "
+              "the parser does not expect you to add variables");
+      auto cbs = std::string{};
+      for (const auto& n : cbn) {
+        cbs += "\n- " + n;
+      }
+      tfel::raise("BehaviourData::addBehaviourVariable: can't add variable '" +
+                  v.name + "' of type '" + v.behaviour.getClassName() +
+                  "', no more variable can be defined. This may mean that "
+                  "you already declared a block of code (or that the dsl "
+                  "does not expect you to add variables for whatever reason). "
+                  "This is the list of code blocks defined:" +
+                  cbs);
+    }
+    this->behaviourVariables.push_back(v);
+  }  // end of addBehaviourVariable
+
+  void BehaviourData::addBehaviourVariableFactory(
+      const BehaviourVariableDescription& v) {
+    if ((this->hasAttribute(BehaviourData::allowsNewUserDefinedVariables)) &&
+        (!this->getAttribute<bool>(
+            BehaviourData::allowsNewUserDefinedVariables))) {
+      const auto cbn = this->getCodeBlockNames();
+      tfel::raise_if(
+          cbn.empty(),
+          "BehaviourData::addBehaviourVariableFactory: can't add  behaviour "
+          "variable factory '" +
+              v.name + "' for behaviour of type '" +
+              v.behaviour.getClassName() +
+              "', no more variable can be defined. This may mean that "
+              "the parser does not expect you to add variables");
+      auto cbs = std::string{};
+      for (const auto& n : cbn) {
+        cbs += "\n- " + n;
+      }
+      tfel::raise(
+          "BehaviourData::addBehaviourVariableFactory: can't add behaviour "
+          "variable factory '" +
+          v.name + "' for behaviour of type '" + v.behaviour.getClassName() +
+          "', no more variable can be defined. This may mean that "
+          "you already declared a block of code (or that the dsl "
+          "does not expect you to add variables for whatever reason). "
+          "This is the list of code blocks defined:" +
+          cbs);
+    }
+    this->behaviourVariableFactories.push_back(v);
+  }  // end of addBehaviourVariableFactory
+
   void BehaviourData::addLocalVariable(const VariableDescription& v,
                                        const RegistrationStatus s) {
     this->addVariable(this->localVariables, v, s, false, true);
@@ -752,6 +822,29 @@ namespace mfront {
     return this->localVariables;
   }  // end of getLocalVariables
 
+  const BehaviourVariableDescription&
+  BehaviourData::getBehaviourVariableFactory(const std::string& n) const {
+    for (const auto& f : this->getBehaviourVariableFactories()) {
+      if (n == getBehaviourVariableFactoryClassName(f)) {
+        return f;
+      }
+    }
+    tfel::raise(
+        "BehaviourData::getBehaviourVariableFactory: "
+        "no behaviour variable factory named '" +
+        n + "'");
+  }  // end of getBehaviourVariableFactory
+
+  const std::vector<BehaviourVariableDescription>&
+  BehaviourData::getBehaviourVariables() const {
+    return this->behaviourVariables;
+  }  // end of getBehaviourVariables
+
+  const std::vector<BehaviourVariableDescription>&
+  BehaviourData::getBehaviourVariableFactories() const {
+    return this->behaviourVariableFactories;
+  }  // end of getBehaviourVariableFactories
+
   bool BehaviourData::isUsableInPurelyImplicitResolution() const {
     return this->usableInPurelyImplicitResolution;
   }  // end of isUsableInPurelyImplicitResolution
@@ -1030,14 +1123,14 @@ namespace mfront {
           const std::string& n) {
     this->pupirv.insert(n);
   }  // end of
-     // BehaviourData::declareExternalStateVariableProbablyUnusableInPurelyImplicitResolution
+     // declareExternalStateVariableProbablyUnusableInPurelyImplicitResolution
 
   const std::set<std::string>& BehaviourData::
       getExternalStateVariablesDeclaredProbablyUnusableInPurelyImplicitResolution()
           const {
     return this->pupirv;
   }  // end of
-     // BehaviourData::getExternalStateVariablesDeclaredProbablyUnusableInPurelyImplicitResolution
+     // getExternalStateVariablesDeclaredProbablyUnusableInPurelyImplicitResolution
 
   void BehaviourData::addVariable(VariableDescriptionContainer& c,
                                   const VariableDescription& v,
@@ -1351,17 +1444,17 @@ namespace mfront {
     pc->second.set(c, p, b);
   }  // end of setCode
 
-  const CodeBlock& BehaviourData::getCodeBlock(const std::string& n) const {
+  const CodeBlock& BehaviourData::getCodeBlock(std::string_view n) const {
     auto p = this->cblocks.find(n);
     tfel::raise_if(p == this->cblocks.end(),
                    "BehaviourData::getCode: "
                    "no code block associated with '" +
-                       n + "'");
+                       std::string{n} + "'");
     return p->second.get();
   }  // end of getCodeBlock
 
-  std::string BehaviourData::getCode(const std::string& n,
-                                     const std::string& cn,
+  std::string BehaviourData::getCode(std::string_view n,
+                                     std::string_view cn,
                                      const bool b) const {
     if (!b) {
       return this->getCodeBlock(n).code;
@@ -1373,7 +1466,7 @@ namespace mfront {
     return out.str();
   }  // end of getCode
 
-  bool BehaviourData::hasCode(const std::string& n) const {
+  bool BehaviourData::hasCode(std::string_view n) const {
     return this->cblocks.find(n) != this->cblocks.end();
   }
 
@@ -1911,7 +2004,58 @@ namespace mfront {
     return initialize_methods;
   }  // end of getUserDefinedInitializeCodeBlocksNames
 
-  void BehaviourData::finalizeVariablesDeclaration() {
+  void BehaviourData::declareMaterialPropertyFromSharedVariable(
+      const BehaviourVariableDescription& bv, const VariableDescription& mp) {
+    if (this->isMaterialPropertyName(mp.name)) {
+      const auto& cmp = this->getMaterialProperties().getVariable(mp.name);
+      checkSharedVariableCompatibility(bv, mp, cmp);
+    } else {
+      this->addMaterialProperty(mp, BehaviourData::UNREGISTRED);
+    }
+  }  // end of declareMaterialPropertyFromSharedVariable
+
+  void BehaviourData::declareExternalStateVariableFromSharedVariable(
+      const BehaviourVariableDescription& bv, const VariableDescription& esv) {
+    if (this->isExternalStateVariableName(esv.name)) {
+      const auto& cesv =
+          this->getExternalStateVariables().getVariable(esv.name);
+      checkSharedVariableCompatibility(bv, esv, cesv);
+    } else {
+      this->addExternalStateVariable(esv, BehaviourData::UNREGISTRED);
+    }
+  }  // end of declareExternalStateVariableFromSharedVariable
+
+  void BehaviourData::finalizeVariablesDeclaration(const Hypothesis h) {
+    //
+    auto finalize = [this, h](const BehaviourVariableDescription& bv) {
+      for (const auto& mp : getSharedMaterialProperties(bv, h)) {
+        try {
+          this->declareMaterialPropertyFromSharedVariable(bv, mp);
+        } catch (std::exception& e) {
+          tfel::raise("Error while treating shared material property '" +
+                      mp.name + "' from behaviour '" + bv.name + "' of type '" +
+                      bv.behaviour.getClassName() + "'. " +
+                      std::string{e.what()});
+        }
+      }
+      for (const auto& esv : getSharedExternalStateVariables(bv, h)) {
+        try {
+          this->declareExternalStateVariableFromSharedVariable(bv, esv);
+        } catch (std::exception& e) {
+          tfel::raise("Error while treating shared external state variable '" +
+                      esv.name + "' from behaviour '" + bv.name +
+                      "' of type '" + bv.behaviour.getClassName() + "'. " +
+                      std::string{e.what()});
+        }
+      }
+    };
+    for (const auto& bv : this->behaviourVariables) {
+      finalize(bv);
+    }
+    for (const auto& bv : this->behaviourVariableFactories) {
+      finalize(bv);
+    }
+    //
     auto check = [](const VariableDescription& v) {
       if (v.getTypeFlag() != SupportedTypes::SCALAR) {
         tfel::raise(
