@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   06 mai 2008
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -21,6 +21,7 @@
 #include "TFEL/Utilities/StringAlgorithms.hxx"
 #include "TFEL/System/System.hxx"
 #include "MFront/DSLUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/MFrontUtilities.hxx"
 #include "MFront/MFrontHeader.hxx"
 #include "MFront/FileDescription.hxx"
@@ -73,10 +74,6 @@ namespace mfront {
     const auto name = this->getCastemFunctionName(mpd);
     const auto tfel_config = tfel::getTFELConfigExecutableName();
     insert_if(l.cppflags, CASTEM_CPPFLAGS);
-    insert_if(l.cppflags,
-              "$(shell " + tfel_config + " --cppflags --compiler-flags)");
-    insert_if(l.include_directories,
-              "$(shell " + tfel_config + " --include-path)");
     insert_if(l.sources, this->getSourceFileName(name));
 #if !((defined _WIN32) && (defined _MSC_VER))
     insert_if(l.link_libraries, "m");
@@ -342,10 +339,12 @@ namespace mfront {
         << "#include<cstdlib>\n"
         << "#include<string>\n"
         << "#include<vector>\n"
+        << "#include<locale>\n"
         << "#include<cmath>\n"
         << "#include\"TFEL/Config/TFELTypes.hxx\"\n"
         << "#include\"TFEL/PhysicalConstants.hxx\"\n"
-        << "#include\"TFEL/Math/General/IEEE754.hxx\"\n\n";
+        << "#include\"TFEL/Math/General/IEEE754.hxx\"\n\n"
+        << "#include\"TFEL/Math/General/DerivativeType.hxx\"\n";
     if (useQuantities(mpd)) {
       out << "#include\"TFEL/Math/qt.hxx\"\n"
           << "#include\"TFEL/Math/Quantity/qtIO.hxx\"\n";
@@ -386,6 +385,20 @@ namespace mfront {
           << "const double v"
           << "){\n";
       for (const auto& p : params) {
+        if (p.getExternalName() != p.name) {
+          out << "if(strcmp(\"" << p.getExternalName() << "\",p) == 0){\n"
+              << "castem::" << hn << "::get" << hn << "()." << p.name
+              << " = v;\n"
+              << "return 1;\n"
+              << "}\n";
+        }
+        if ((!p.symbolic_form.empty()) && (p.symbolic_form != p.name)) {
+          out << "if(strcmp(\"" << p.symbolic_form << "\",p) == 0){\n"
+              << "castem::" << hn << "::get" << hn << "()." << p.name
+              << " = v;\n"
+              << "return 1;\n"
+              << "}\n";
+        }
         out << "if(strcmp(\"" << p.name << "\",p)==0){\n"
             << "castem::" << hn << "::get" << hn << "()." << p.name << " = v;\n"
             << "return 1;\n"
