@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   17 Jan 2007
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -25,11 +25,14 @@
 #include "TFEL/Utilities/StringAlgorithms.hxx"
 #include "TFEL/System/System.hxx"
 
+#include "MFront/MFrontWarningMode.hxx"
 #include "MFront/DSLUtilities.hxx"
 #include "MFront/MFrontUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/MFrontLogStream.hxx"
 #include "MFront/FileDescription.hxx"
 #include "MFront/TargetsDescription.hxx"
+#include "MFront/VariableDescription.hxx"
 #include "MFront/MaterialPropertyDescription.hxx"
 #include "MFront/CyranoMaterialPropertyInterface.hxx"
 #include "MFront/CyranoSymbolsGenerator.hxx"
@@ -117,27 +120,60 @@ namespace mfront {
       if (std::find(i.begin(), i.end(), this->getName()) == i.end()) {
         return {false, current};
       }
+      auto keys = {"@CyranoGenerateMTestFileOnFailure",
+                   "@UMATGenerateMTestFileOnFailure",
+                   "@GenerateMTestFileOnFailure",
+                   "@CyranoUseTimeSubStepping",
+                   "@UMATUseTimeSubStepping",
+                   "@CyranoMaximumSubStepping",
+                   "@UMATMaximumSubStepping",
+                   "@CyranoDoSubSteppingOnInvalidResults",
+                   "@UMATDoSubSteppingOnInvalidResults"};
+      throw_if(std::find(keys.begin(), keys.end(), key) == keys.end(),
+               "unsupported key '" + key + "'");
     }
+    auto check_interface_restriction = [this, &i, &key] {
+      if (i.empty()) {
+        reportWarning("keyword '" + key +
+                      "' is used without being restricted to the " +
+                      this->getName() +
+                      " interface, which could be a portability "
+                      "issue. Please add [" +
+                      this->getName() + "] after the keyword (i.e. replace '" +
+                      key + "' by '" + key + "[" + this->getName() + "]')");
+      }
+    };
     if ((key == "@CyranoGenerateMTestFileOnFailure") ||
         (key == "@UMATGenerateMTestFileOnFailure") ||
         (key == "@GenerateMTestFileOnFailure")) {
+      if (key != "@GenerateMTestFileOnFailure") {
+        check_interface_restriction();
+      }
       this->setGenerateMTestFileOnFailureAttribute(
           bd, this->readBooleanValue(key, current, end));
       return {true, current};
     } else if ((key == "@CyranoUseTimeSubStepping") ||
                (key == "@UMATUseTimeSubStepping")) {
+      check_interface_restriction();
       this->useTimeSubStepping = this->readBooleanValue(key, current, end);
       return {true, current};
     } else if ((key == "@CyranoMaximumSubStepping") ||
                (key == "@UMATMaximumSubStepping")) {
+      check_interface_restriction();
       throw_if(!this->useTimeSubStepping,
                "time sub stepping is not enabled at this stage.\n"
                "Use the @CyranoUseTimeSubStepping directive before "
                "@CyranoMaximumSubStepping");
+      const bool safe = readSafeOptionTypeIfPresent(current, end);
       throw_if(current == end, "unexpected end of file");
       std::istringstream flux(current->value);
       flux >> this->maximumSubStepping;
       throw_if(flux.fail(), "failed to read maximum substepping value.");
+      if ((this->maximumSubStepping > 3) && (!safe)) {
+        reportWarning("the maximum number of substeps specified is to high (" +
+                      std::to_string(this->maximumSubStepping) +
+                      "). It is recommended to allow at most 3 substeps.");
+      }
       ++(current);
       throw_if(current == end, "unexpected end of file");
       throw_if(current->value != ";",
@@ -146,6 +182,7 @@ namespace mfront {
       return {true, current};
     } else if ((key == "@CyranoDoSubSteppingOnInvalidResults") ||
                (key == "@UMATDoSubSteppingOnInvalidResults")) {
+      check_interface_restriction();
       throw_if(!this->useTimeSubStepping,
                "time sub stepping is not "
                "enabled at this stage.\n"
@@ -412,8 +449,6 @@ namespace mfront {
         ((!bd.getLibrary().empty()) ? bd.getLibrary() : "") + bd.getClassName();
     const auto tfel_config = tfel::getTFELConfigExecutableName();
     auto& l = d.getLibrary(lib);
-    insert_if(l.cppflags,
-              "$(shell " + tfel_config + " --cppflags --compiler-flags)");
 #if CYRANO_ARCH == 64
     insert_if(l.cppflags, "-DCYRANO_ARCH=64");
 #elif CYRANO_ARCH == 32
@@ -421,8 +456,6 @@ namespace mfront {
 #else
 #error "CyranoInterface::getGlobalIncludes : unsuported architecture"
 #endif
-    insert_if(l.include_directories,
-              "$(shell " + tfel_config + " --include-path)");
     insert_if(l.sources, "cyrano" + name + ".cxx");
     insert_if(l.epts, this->getFunctionNameBasis(name));
     insert_if(d.headers, "MFront/Cyrano/cyrano" + name + ".hxx");
