@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   06 mai 2008
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -31,14 +31,14 @@
 #include <io.h>
 #define F_OK 0 /* Test for existence.  */
 #ifndef S_ISREG
-#define S_ISREG(mode) (((mode) & S_IFMT) == S_IFREG)
+#define S_ISREG(mode) (((mode)&S_IFMT) == S_IFREG)
 #endif
 #endif
 
 #include "TFEL/Raise.hxx"
 #include "TFEL/System/System.hxx"
-
 #include "MFront/DSLUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/MFrontHeader.hxx"
 #include "MFront/MFrontLock.hxx"
 #include "MFront/FileDescription.hxx"
@@ -156,6 +156,8 @@ namespace mfront {
       interfaces2[i.library].push_back(i);
       wrapper << '\n';
     }
+    wrapper.close();
+    //
     for (const auto& i : interfaces2) {
       const auto& libName = i.first;
       std::ofstream file("src/" + libName + ".bas");
@@ -172,7 +174,42 @@ namespace mfront {
         file << ") As Double\n";
       }
     }
-    wrapper.close();
+    tfel::system::systemCall::mkdir("excel");
+    for (const auto& i : interfaces2) {
+      const auto& libName = i.first;
+      std::ofstream file("excel/" + libName + "-64bits.bas");
+      throw_if(!file, "unable to open file 'src/" + libName + ".bas'");
+      for (const auto& f : i.second) {
+        file << "Declare PtrSafe Function " << f.function
+             << "_mfront_impl_ Lib \"" << libName << ".dll\"  Alias \""
+             << f.function << "\" (";
+        for (auto p6 = f.variables.cbegin(); p6 != f.variables.cend();) {
+          file << "ByVal " << *p6 << " As Double";
+          if (++p6 != f.variables.end()) {
+            file << ", ";
+          }
+        }
+        file << ") As Double\n\n";
+        file << "Function " << f.function << " (";
+        for (auto p6 = f.variables.cbegin(); p6 != f.variables.cend();) {
+          file << "ByVal " << *p6 << " As Double";
+          if (++p6 != f.variables.end()) {
+            file << ", ";
+          }
+        }
+        file << ") As Double\n";
+        file << f.function << " = " << f.function << "_mfront_impl_(";
+        for (auto p6 = f.variables.cbegin(); p6 != f.variables.cend();) {
+          file << *p6;
+          if (++p6 != f.variables.end()) {
+            file << ", ";
+          }
+        }
+        file << ")\n";
+        file << "End Function\n";
+      }
+    }
+
   }  // end of ExcelMaterialPropertyInterface::writeSrcFile()
 
 }  // end of namespace mfront
