@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   04/05/2022
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -27,6 +27,7 @@
 #include "MFront/MFrontHeader.hxx"
 #include "MFront/MFrontLock.hxx"
 #include "MFront/DSLUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/MFrontUtilities.hxx"
 #include "MFront/FileDescription.hxx"
 #include "MFront/LibraryDescription.hxx"
@@ -63,10 +64,6 @@ namespace mfront {
       const MaterialPropertyDescription& mpd) const {
     const auto name = this->getFunctionName(mpd);
     const auto tfel_config = tfel::getTFELConfigExecutableName();
-    insert_if(l.cppflags,
-              "$(shell " + tfel_config + " --cppflags --compiler-flags)");
-    insert_if(l.include_directories,
-              "$(shell " + tfel_config + " --include-path)");
     insert_if(l.sources, this->getSourceFileName(name));
 #if !((defined _WIN32) && (defined _MSC_VER))
     insert_if(l.link_libraries, "m");
@@ -341,10 +338,12 @@ namespace mfront {
        << "#include<cerrno>\n"
        << "#include<string>\n"
        << "#include<vector>\n"
+       << "#include<locale>\n"
        << "#include<cmath>\n"
        << "#include\"TFEL/Config/TFELTypes.hxx\"\n"
        << "#include\"TFEL/PhysicalConstants.hxx\"\n"
-       << "#include\"TFEL/Math/General/IEEE754.hxx\"\n";
+       << "#include\"TFEL/Math/General/IEEE754.hxx\"\n"
+       << "#include\"TFEL/Math/General/DerivativeType.hxx\"\n";
     if (useQuantities(mpd)) {
       os << "#include\"TFEL/Math/qt.hxx\"\n"
          << "#include\"TFEL/Math/Quantity/qtIO.hxx\"\n";
@@ -385,6 +384,20 @@ namespace mfront {
          << "const double v"
          << "){\n";
       for (const auto& p : params) {
+        if (p.getExternalName() != p.name) {
+          os << "if(strcmp(\"" << p.getExternalName() << "\",p) == 0){\n"
+             << iname << "::" << hn << "::get" << hn << "()." << p.name
+             << " = v;\n"
+             << "return 1;\n"
+             << "}\n";
+        }
+        if ((!p.symbolic_form.empty()) && (p.symbolic_form != p.name)) {
+          os << "if(strcmp(\"" << p.symbolic_form << "\",p) == 0){\n"
+             << iname << "::" << hn << "::get" << hn << "()." << p.name
+             << " = v;\n"
+             << "return 1;\n"
+             << "}\n";
+        }
         os << "if(strcmp(\"" << p.name << "\",p) == 0){\n"
            << iname << "::" << hn << "::get" << hn << "()." << p.name
            << " = v;\n"
