@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   15/03/2018
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -50,6 +50,30 @@ namespace mfront::bbrick {
         "if appropriate, save the porosity increase induced "
         "by this inelastic flow in a dedicated auxiliary state variable",
         OptionDescription::BOOLEAN);
+    opts.emplace_back(
+        "equivalent_strain_external_name",
+        "external name of the equivalent (plastic or viscoplastic) strain.",
+        OptionDescription::STRING);
+    opts.emplace_back(
+        "save_stress_criterion",
+        "flag stating if the stress criterion in the middle of the time step "
+        "shall be saved in a dedicated auxiliary state variable",
+        OptionDescription::BOOLEAN);
+    opts.emplace_back("stress_criterion_external_name",
+                      "external name of the auxiliary state variable in which "
+                      "the stress criterion shall be saved if the "
+                      "save_stress_criterion option is `true.",
+                      OptionDescription::STRING);
+    opts.emplace_back("save_yield_surface_radius",
+                      "flag stating if the yield surface radius in the middle "
+                      "of the time step "
+                      "shall be saved in a dedicated auxiliary state variable",
+                      OptionDescription::BOOLEAN);
+    opts.emplace_back("yield_surface_radius_external_name",
+                      "external name of the auxiliary state variable in which "
+                      "the yield surface radius shall be saved if the "
+                      "save_yield_surface_radius option is `true.",
+                      OptionDescription::STRING);
     opts.emplace_back(
         "porosity_effect_on_equivalent_plastic_strain",
         "specify the effect of the porosity of the flow rule. "
@@ -118,6 +142,9 @@ namespace mfront::bbrick {
       getLogStream() << "checking options\n";
     }
     this->checkOptions(d);
+    //
+    this->stress_criterion_external_name = "EquivalentStress" + id;
+    this->yield_surface_radius_external_name = "YieldSurfaceRadius" + id;
     // parsing options
     for (const auto& e : d) {
       if (e.first == "criterion") {
@@ -194,6 +221,31 @@ namespace mfront::bbrick {
         } else {
           add_kinematic_hardening_rule(getDataStructure(e.first, e.second));
         }
+      } else if (e.first == "equivalent_strain_external_name") {
+        if (!e.second.is<std::string>()) {
+          raise("'equivalent_strain_external_name' is not a string");
+        }
+        this->equivalent_strain_external_name = e.second.get<std::string>();
+      } else if (e.first == "stress_criterion_external_name") {
+        if (!e.second.is<std::string>()) {
+          raise("'stress_criterion_external_name' is not a string");
+        }
+        this->stress_criterion_external_name = e.second.get<std::string>();
+      } else if (e.first == "save_stress_criterion") {
+        if (!e.second.is<bool>()) {
+          raise("'save_stress_criterion' is not a boolean");
+        }
+        this->save_stress_criterion = e.second.get<bool>();
+      } else if (e.first == "yield_surface_radius_external_name") {
+        if (!e.second.is<std::string>()) {
+          raise("'yield_surface_radius_external_name' is not a string");
+        }
+        this->yield_surface_radius_external_name = e.second.get<std::string>();
+      } else if (e.first == "save_yield_surface_radius") {
+        if (!e.second.is<bool>()) {
+          raise("'save_yield_surface_radius' is not a boolean");
+        }
+        this->save_yield_surface_radius = e.second.get<bool>();
       } else if (e.first == "save_porosity_increase") {
         if (!e.second.is<bool>()) {
           raise("'save_porosity_increase' is not a boolean");
@@ -306,7 +358,7 @@ namespace mfront::bbrick {
       if (this->ihrs.size() != 1) {
         const auto Rel = "Rel" + id;
         const auto R = "R" + id;
-        const auto dR = "d" + R + "_ddp" + id;
+        const auto dR = "d" + R + "_dp" + id;
         bd.reserveName(uh, Rel);
         bd.reserveName(uh, R);
         bd.reserveName(uh, dR);
@@ -349,6 +401,36 @@ namespace mfront::bbrick {
         bd.addAuxiliaryStateVariable(uh, fg);
       }
     }
+    if (this->save_stress_criterion) {
+      const auto n = "mfront_" + this->stress_criterion_external_name;
+      VariableDescription stress_criterion("stress", n, 1u, 0u);
+      const auto& g = tfel::glossary::Glossary::getGlossary();
+      if (g.contains(this->stress_criterion_external_name)) {
+        stress_criterion.setGlossaryName(this->stress_criterion_external_name);
+      } else {
+        stress_criterion.setEntryName(this->stress_criterion_external_name);
+      }
+      bd.addAuxiliaryStateVariable(uh, stress_criterion);
+    }
+    if (this->save_yield_surface_radius) {
+      if (this->ihrs.empty()) {
+        raise(
+            "InelasticFlowBase::initialize: "
+            "`save_yield_surface_radius` is set to true, but no isotropic "
+            "hardening rule is defined");
+      }
+      const auto n = "mfront_" + this->yield_surface_radius_external_name;
+      VariableDescription yield_surface_radius("stress", n, 1u, 0u);
+      const auto& g = tfel::glossary::Glossary::getGlossary();
+      if (g.contains(this->yield_surface_radius_external_name)) {
+        yield_surface_radius.setGlossaryName(
+            this->yield_surface_radius_external_name);
+      } else {
+        yield_surface_radius.setEntryName(
+            this->yield_surface_radius_external_name);
+      }
+      bd.addAuxiliaryStateVariable(uh, yield_surface_radius);
+    }
   }  // end of initialize
 
   void InelasticFlowBase::setPorosityEvolutionHandled(const bool b) {
@@ -418,6 +500,14 @@ namespace mfront::bbrick {
       i.code += this->sc->computeElasticPrediction(id, bd, sp);
       i.code += computeElasticLimitInitialValue(bd, this->ihrs, id);
       i.code += "this->bpl" + id + " = seqel" + id + " > Rel" + id + ";\n";
+      if (this->save_stress_criterion) {
+        i.code += "this->mfront_" + stress_criterion_external_name +
+                  " = seqel" + id + ";\n";
+      }
+      if (this->save_yield_surface_radius) {
+        i.code += "this->mfront_" + yield_surface_radius_external_name +
+                  " = Rel" + id + ";\n";
+      }
       bd.setCode(ModellingHypothesis::UNDEFINEDHYPOTHESIS,
                  BehaviourData::BeforeInitializeLocalVariables, i,
                  BehaviourData::CREATEORAPPEND, BehaviourData::AT_BEGINNING);
@@ -516,6 +606,10 @@ namespace mfront::bbrick {
             this->fc->computeNormal(id, bd, sp, StressCriterion::FLOWCRITERION);
       }
     }
+    if (this->save_stress_criterion) {
+      ib.code += "this->mfront_" + stress_criterion_external_name + " = seq" +
+                 id + ";\n";
+    }
     // check on the flow direction
     if (this->cosine_threshold < 1.5) {
       const auto imin =
