@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   06 mai 2008
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -29,7 +29,7 @@
 #include <io.h>
 #define F_OK 0 /* Test for existence.  */
 #ifndef S_ISREG
-#define S_ISREG(mode) (((mode) & S_IFMT) == S_IFREG)
+#define S_ISREG(mode) (((mode)&S_IFMT) == S_IFREG)
 #endif
 #endif
 
@@ -41,6 +41,8 @@
 #include "MFront/MFrontHeader.hxx"
 #include "MFront/MFrontLock.hxx"
 #include "MFront/DSLUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
+#include "MFront/MFrontWarningMode.hxx"
 #include "MFront/MFrontUtilities.hxx"
 #include "MFront/FileDescription.hxx"
 #include "MFront/TargetsDescription.hxx"
@@ -86,6 +88,15 @@ namespace mfront {
       throw_if(key != "@Package", "unsupported key '" + key + "'");
     }
     if (key == "@Package") {
+      if (i.empty()) {
+        reportWarning("keyword '" + key +
+                      "' is used without being restricted to the " +
+                      this->getName() +
+                      " interface, which could be a portability "
+                      "issue. Please add [" +
+                      this->getName() + "] after the keyword (i.e. replace '" +
+                      key + "' by '" + key + "[" + this->getName() + "]')");
+      }
       throw_if(!this->package.empty(), "package name already defined");
       throw_if(current == end, "unexpected end of file");
       const auto p = current->value;
@@ -121,10 +132,6 @@ namespace mfront {
 #endif /* !((defined _WIN32) && (defined _MSC_VER)) */
     // the jni part
     insert_if(l.cppflags, TFEL_JAVA_INCLUDES);
-    insert_if(l.cppflags,
-              "$(shell " + tfel_config + " --cppflags --compiler-flags)");
-    insert_if(l.include_directories,
-              "$(shell " + tfel_config + " --include-path)");
     insert_if(l.sources, name + "-java.cxx");
     if (this->package.empty()) {
       insert_if(l.epts, getJavaClassName(mpd) + "." + mpd.law);
@@ -309,7 +316,8 @@ namespace mfront {
             << "#include<cmath>\n\n"
             << "#include\"TFEL/Config/TFELTypes.hxx\"\n"
             << "#include\"TFEL/PhysicalConstants.hxx\"\n"
-            << "#include\"TFEL/Math/General/IEEE754.hxx\"\n\n";
+            << "#include\"TFEL/Math/General/IEEE754.hxx\"\n\n"
+            << "#include\"TFEL/Math/General/DerivativeType.hxx\"\n";
     if (useQuantities(mpd)) {
       srcFile << "#include\"TFEL/Math/qt.hxx\"\n"
               << "#include\"TFEL/Math/Quantity/qtIO.hxx\"\n";
