@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   04 mars 2015
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -30,9 +30,9 @@
 #include "MFront/SearchPathsHandler.hxx"
 #include "MFront/PedanticMode.hxx"
 #include "MFront/MFrontLogStream.hxx"
+#include "MFront/MFrontWarningMode.hxx"
 #include "MFront/MFrontDebugMode.hxx"
 #include "MFront/MFrontUtilities.hxx"
-#include "MFront/DSLUtilities.hxx"
 #include "MFront/DefaultDSL.hxx"
 #include "MFront/DSLFactory.hxx"
 #include "MFront/PathSpecifier.hxx"
@@ -78,11 +78,14 @@ namespace mfront {
         throw_if(pt == pte, "unexpected end of file (exepected dsl name)");
         if (pt->value == "{") {
           const auto o = tfel::utilities::DataParsingOptions{};
-          ldsl_options =
-              tfel::utilities::merge(ldsl_options,
-                                     tfel::utilities::Data::read(pt, pte, o)
-                                         .get<tfel::utilities::DataMap>(),
-                                     false);
+          const auto opts = [&o, &pt, &pte] {
+            const auto options = tfel::utilities::Data::read(pt, pte, o);
+            if (options.empty()) {
+              return tfel::utilities::DataMap{};
+            }
+            return options.get<tfel::utilities::DataMap>();
+          }();
+          ldsl_options = tfel::utilities::merge(ldsl_options, opts, false);
         }
         throw_if(pt == pte,
                  "unexpected end of file (exepected ';' or library name)");
@@ -463,7 +466,41 @@ namespace mfront {
 
   void MFrontBase::treatPedantic() { setPedanticMode(true); }
 
-  void MFrontBase::treatWarning() {}
+  void MFrontBase::treatReportWarnings() {
+    const auto& o = this->getCurrentCommandLineArgument().getOption();
+    if (o.empty()) {
+      setWarningMode(true);
+    } else {
+      if (o == "true") {
+        setWarningMode(true);
+      } else if (o == "false") {
+        setWarningMode(false);
+      } else {
+        tfel::raise(
+            "MFrontBase::treatReportWarnings: "
+            "unknown option '" +
+            o + "'");
+      }
+    }
+  }  // end of treatReportWarnings
+
+  void MFrontBase::treatWarningError() {
+    const auto& o = this->getCurrentCommandLineArgument().getOption();
+    if (o.empty()) {
+      setWarningErrorMode(true);
+    } else {
+      if (o == "true") {
+        setWarningErrorMode(true);
+      } else if (o == "false") {
+        setWarningErrorMode(false);
+      } else {
+        tfel::raise(
+            "MFrontBase::treatWarningError: "
+            "unknown option '" +
+            o + "'");
+      }
+    }
+  }  // end of treatWarningError
 
   void MFrontBase::treatDebug() { setDebugMode(true); }
 
@@ -514,8 +551,8 @@ namespace mfront {
     t.parseString('{' + std::string{std::istreambuf_iterator<char>{ifs}, {}} +
                   '}');
     auto b = t.begin();
-    const auto data = tfel::utilities::Data::read(b, t.end());
-    for (const auto& d : data.get<tfel::utilities::DataMap>()) {
+    const auto data = read<tfel::utilities::DataMap>(b, t.end());
+    for (const auto& d : data) {
       callback(d.first, d.second);
     }
   }  // end of parseDSLOptionsFile
