@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   10 Nov 2006
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -30,7 +30,7 @@
 
 #include "MFront/MFrontHeader.hxx"
 #include "MFront/MFrontLogStream.hxx"
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/MFrontUtilities.hxx"
 #include "MFront/PedanticMode.hxx"
 #include "MFront/MFrontDebugMode.hxx"
@@ -76,6 +76,8 @@ namespace mfront {
     this->registerNewCallBack(";", &MaterialPropertyDSL::treatLonelySeparator);
     this->registerNewCallBack("@UseQt", &MaterialPropertyDSL::treatUseQt);
     this->registerNewCallBack("@Link", &MaterialPropertyDSL::treatLink);
+    this->registerNewCallBack("@TFELLibraries",
+                              &MaterialPropertyDSL::treatTFELLibraries);
     this->registerNewCallBack("@MaterialLaw",
                               &MaterialPropertyDSL::treatMaterialLaw);
     this->registerNewCallBack("@MFront", &MaterialPropertyDSL::treatMFront);
@@ -243,10 +245,13 @@ namespace mfront {
   }  // end of doPedanticChecks
 
   void MaterialPropertyDSL::endsInputFileProcessing() {
+  }  // end of endsInputFileProcessing
+
+  void MaterialPropertyDSL::makeConsistencyChecks() const {
     if (getPedanticMode()) {
       this->doPedanticChecks();
     }
-  }  // end of endsInputFileProcessing
+  }  // end of makeConsistencyChecks
 
   void MaterialPropertyDSL::registerNewCallBack(const std::string& keyword,
                                                 const MemberFuncPtr ptr) {
@@ -487,8 +492,7 @@ namespace mfront {
           std::find_if(this->md.inputs.begin(), this->md.inputs.end(), match);
       auto pp = std::find_if(this->md.parameters.begin(),
                              this->md.parameters.end(), match);
-      if ((pi == this->md.inputs.end()) &&
-          (pp == this->md.parameters.end())) {
+      if ((pi == this->md.inputs.end()) && (pp == this->md.parameters.end())) {
         tfel::raise(
             "MaterialPropertyDSL::finalizeVariablesDeclaration: "
             "no variable named '" +
@@ -533,8 +537,7 @@ namespace mfront {
 
   void MaterialPropertyDSL::treatDataWithoutInput() {
     using namespace tfel::utilities;
-    const auto opts =
-        Data::read(this->current, this->tokens.end()).get<DataMap>();
+    const auto opts = read<DataMap>(this->current, this->tokens.end());
     for (const auto& [k, v] : opts) {
       if (k != "value") {
         this->throwRuntimeError("MaterialPropertyDSL::treatData",
@@ -560,7 +563,7 @@ namespace mfront {
     auto& body = this->md.f.body;
     const auto& v = this->md.inputs[0];
     const auto idata = SingleVariableInterpolatedData::extract(
-        Data::read(this->current, this->tokens.end()).get<DataMap>());
+        read<DataMap>(this->current, this->tokens.end()));
     if (idata.itype == SingleVariableInterpolatedData::LINEAR_INTERPOLATION) {
       if (idata.values.size() == 1) {
         const auto value = idata.values.begin()->second;
@@ -762,7 +765,7 @@ namespace mfront {
     throw_if(openedBrackets != 0,
              "parenthesis still opened at the end of function");
     throw_if(this->md.f.body.empty(), "empty function");
-    throw_if(!this->md.f.modified, "function does not modifiy output.");
+    throw_if(!this->md.f.modified, "function does not modify output.");
   }  // end of treatFunction
 
   void MaterialPropertyDSL::treatMethod() {
@@ -923,6 +926,7 @@ namespace mfront {
       const std::map<std::string, std::string>& s) {
     this->importFile(fileName_, ecmds, s);
     this->endsInputFileProcessing();
+    this->makeConsistencyChecks();
     for (const auto& i : this->interfaces) {
       i.second->getTargetsDescription(this->td, this->md);
     }
@@ -943,8 +947,10 @@ namespace mfront {
   }  // end of disableQuantitiesUsageIfNotAlreadySet
 
   void MaterialPropertyDSL::addExternalMFrontFile(
-      const std::string& f, const std::vector<std::string>& vinterfaces) {
-    this->md.addExternalMFrontFile(f, vinterfaces);
+      const std::string& f,
+      const std::vector<std::string>& vinterfaces,
+      const tfel::utilities::DataMap& dsl_options) {
+    this->md.addExternalMFrontFile(f, vinterfaces, dsl_options);
   }  // end of addExternalMFrontFile
 
   const MaterialKnowledgeDescription&
@@ -973,7 +979,8 @@ namespace mfront {
     }
     //! generating sources du to external material properties and models
     for (const auto& em : this->md.getExternalMFrontFiles()) {
-      this->callMFront(em.second, {em.first});
+      this->callMFront({em.first}, std::get<0>(em.second),
+                       std::get<1>(em.second));
     }
     // calling interfaces
     for (const auto& i : this->interfaces) {
