@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \brief 11 jun 2010
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -11,6 +11,7 @@
  * project under specific licensing conditions.
  */
 
+#include <locale>
 #include <sstream>
 #include <stdexcept>
 #include <algorithm>
@@ -21,7 +22,6 @@
 #include "TFEL/Utilities/StringAlgorithms.hxx"
 #include "TFEL/UnicodeSupport/UnicodeSupport.hxx"
 #include "MFront/PedanticMode.hxx"
-#include "MFront/DSLUtilities.hxx"
 #include "MFront/MFrontLogStream.hxx"
 #include "MFront/MFrontDebugMode.hxx"
 #include "MFront/ModelDSLCommon.hxx"
@@ -112,7 +112,7 @@ namespace mfront {
         "unimplemented feature");
   }  // end of getOverridableVariableNameByExternalName
 
-  void ModelDSLCommon::overrideByAParameter(const std::string&, const double) {
+  void ModelDSLCommon::overrideByAParameter(const std::string&, const double){
 #pragma message("unimplemented")
   }  // end of overrideByAParameter
 
@@ -128,11 +128,13 @@ namespace mfront {
     }
     // complete the declaration of physical bounds
     this->md.checkAndCompletePhysicalBoundsDeclaration();
+  }  // end of endsInputFileProcessing
 
+  void ModelDSLCommon::makeConsistencyChecks() const {
     if (getPedanticMode()) {
       this->doPedanticChecks();
     }
-  }  // end of endsInputFileProcessing
+  }
 
   bool ModelDSLCommon::useQt() const {
     return this->md.use_qt.has_value() ? *(this->md.use_qt) : false;
@@ -277,7 +279,8 @@ namespace mfront {
     }
     //! generating sources du to external material properties and models
     for (const auto& em : this->md.getExternalMFrontFiles()) {
-      this->callMFront(em.second, {em.first});
+      this->callMFront({em.first}, std::get<0>(em.second),
+                       std::get<1>(em.second));
     }
     //! generating sources by the interfaces
     for (const auto& i : this->interfaces) {
@@ -765,6 +768,7 @@ namespace mfront {
                               "Expected depth value.");
       unsigned short value;
       std::istringstream converter(this->current->value);
+      converter.imbue(std::locale::classic());
       converter >> value;
       if (!converter || (!converter.eof())) {
         this->throwRuntimeError(
@@ -1077,8 +1081,10 @@ namespace mfront {
   }  // end of appendToSources
 
   void ModelDSLCommon::addExternalMFrontFile(
-      const std::string& f, const std::vector<std::string>& vinterfaces) {
-    this->md.addExternalMFrontFile(f, vinterfaces);
+      const std::string& f,
+      const std::vector<std::string>& vinterfaces,
+      const tfel::utilities::DataMap& dsl_options) {
+    this->md.addExternalMFrontFile(f, vinterfaces, dsl_options);
   }  // end of addExternalMFrontFile
 
   const MaterialKnowledgeDescription&
