@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   04/08/2022
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -12,8 +12,9 @@
  */
 
 #include <ostream>
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/MFrontDebugMode.hxx"
+#include "MFront/IsotropicBehaviourDSLBase.hxx"
 #include "MFront/MultipleIsotropicMisesFlowsCodeGenerator.hxx"
 
 namespace mfront {
@@ -35,7 +36,7 @@ namespace mfront {
 
   void
   MultipleIsotropicMisesFlowsCodeGenerator::writeBehaviourParserSpecificMembers(
-      std::ostream& os, const Hypothesis) const {
+      std::ostream& os, const Hypothesis h) const {
     const auto has_plastic_flow = [this] {
       for (auto p = this->flows.begin(); p != this->flows.end(); ++p) {
         if (p->flow == FlowHandler::PlasticFlow) {
@@ -69,6 +70,10 @@ namespace mfront {
       os << "using namespace tfel::material;\n";
       os << "using std::vector;\n";
       writeMaterialLaws(os, this->bd.getMaterialLaws());
+      const auto flow_id = std::to_string(n);
+      if (this->bd.hasCode(h, BehaviourData::BeforeFlowRule + flow_id)) {
+        os << this->bd.getCode(h, BehaviourData::BeforeFlowRule + flow_id);
+      }
       os << p->flowRule << '\n';
       os << "}\n\n";
     }
@@ -295,7 +300,7 @@ namespace mfront {
        << "* \\brief Integrate behaviour law over the time step\n"
        << "*/\n"
        << "[[nodiscard]] IntegrationResult\n"
-       << "integrate(const SMFlag smflag,const SMType smt) override{\n"
+       << "integrate(const SMFlag smflag,const SMType smt) override final{\n"
        << "using namespace std;\n";
     if (this->bd.useQt()) {
       os << "if(smflag!=MechanicalBehaviour<" << btype
@@ -308,6 +313,40 @@ namespace mfront {
          << "throw(runtime_error(\"invalid tangent operator flag\"));\n"
          << "}\n";
     }
+    if (this->bd.hasCode(h, BehaviourData::ComputePredictor)) {
+      os << this->bd.getCode(h, BehaviourData::ComputePredictor) << '\n';
+    }
+    this->writeBehaviourIntegratorPreprocessingStep(os);
+    os << "this->seq_e = sigmaeq(this->se);\n";
+    n = 0;
+    for (const auto& f : this->flows) {
+      if (f.hasSpecificTheta) {
+        if (this->bd.getAttribute(
+                IsotropicBehaviourDSLBase::useStressUpdateAlgorithm, false)) {
+          if (this->shallComputeTheElasticStrain()) {
+            os << "const StressStensor mfront_se" << n << " = "
+               << "2 * (this->mu) * (tfel::math::deviator(mfront_eel_bts + ("
+               << f.theta << ") * (this->deto)));\n";
+          } else {
+            os << "const StressStensor mfront_se" << n << " = "
+               << "tfel::math::deviator(this->sig) + "
+               << "2 * (this->mu) * (" << f.theta << ") * (this->deto);\n";
+          }
+        } else {
+          os << "const StressStensor mfront_se" << n << " = "
+             << "2 * (this->mu) * (tfel::math::deviator(this->eel + ("
+             << f.theta << ") * (this->deto)));\n";
+        }
+        os << "this->seq_e" << n << " = sigmaeq(mfront_se" << n << ");\n";
+      }
+      ++n;
+    }
+    os << "if(this->seq_e > 100 * (this->young) * "
+       << "std::numeric_limits<NumericType>::epsilon()){\n"
+       << "this->n = 3 * (this->se) / (2 * this->seq_e);\n"
+       << "} else {\n"
+       << "this->n = StrainStensor(strain(0));\n"
+       << "}\n";
     os << "if(!this->NewtonIntegration()){\n";
     if (this->bd.useQt()) {
       os << "return MechanicalBehaviour<" << btype
@@ -339,13 +378,8 @@ namespace mfront {
          << ",hypothesis, NumericType,false>::FAILURE;\n";
     }
     os << "}\n"
-       << "}\n"
-       << "this->deel = this->deto-dp*(this->n);\n"
-       << "this->updateStateVariables();\n"
-       << "this->sig  = "
-          "(this->lambda)*trace(this->eel)*StrainStensor::Id()+2*(this->mu)*("
-          "this->eel);\n"
-       << "this->updateAuxiliaryStateVariables();\n";
+       << "}\n";
+    this->writeBehaviourIntegratorPostprocessingStep(os);
     if (!areRuntimeChecksDisabled(this->bd)) {
       for (const auto& v : d.getPersistentVariables()) {
         this->writePhysicalBoundsChecks(os, v, false);
@@ -380,32 +414,7 @@ namespace mfront {
        << "}\n\n";
   }
 
-  void MultipleIsotropicMisesFlowsCodeGenerator::
-      writeBehaviourParserSpecificInitializeMethodPart(std::ostream& os,
-                                                       const Hypothesis) const {
-    this->checkBehaviourFile(os);
-    os << "this->se=2*(this->mu)*(tfel::math::deviator(this->eel+("
-       << this->bd.getClassName() << "::theta)*(this->deto)));\n"
-       << "this->seq_e = sigmaeq(this->se);\n";
-    unsigned short n = 0;
-    for (const auto& f : this->flows) {
-      if (f.hasSpecificTheta) {
-        os << "StressStensor se" << n
-           << "=2*(this->mu)*(tfel::math::deviator(this->eel+(";
-        os << f.theta << ")*(this->deto)));\n";
-        os << "this->seq_e" << n << " = sigmaeq(se" << n << ");\n";
-      }
-      ++n;
-    }
-    os << "if(this->seq_e > 100 * (this->young) * "
-       << "std::numeric_limits<NumericType>::epsilon()){\n"
-       << "this->n = 3 * (this->se) / (2 * this->seq_e);\n"
-       << "} else {\n"
-       << "this->n = StrainStensor(strain(0));\n"
-       << "}\n";
-  }  // end of writeBehaviourParserSpecificInitializeMethodPart
-
   MultipleIsotropicMisesFlowsCodeGenerator::
       ~MultipleIsotropicMisesFlowsCodeGenerator() = default;
 
-}  // end of namespace mfront
\ No newline at end of file
+}  // end of namespace mfront
