@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   28/03/2018
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -142,7 +142,8 @@ namespace mfront::bbrick {
     auto c = std::string{};
     if (this->ihrs.empty()) {
       if (!this->Ksf.empty()) {
-        c += "if(seq" + id + " > (this->Ksf" + id + ") * (this->K" + id + ")){\n";
+        c += "if(seq" + id + " > (this->Ksf" + id + ") * (this->K" + id +
+             ")){\n";
         c += "return false;\n";
         c += "}\n";
       }
