@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   01/10/2020
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -21,7 +21,7 @@
 #include "TFEL/Raise.hxx"
 #include "TFEL/Utilities/StringAlgorithms.hxx"
 #include "TFEL/System/System.hxx"
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/SearchPathsHandler.hxx"
 #include "MFront/MaterialKnowledgeDescription.hxx"
 #include "MFront/FileDescription.hxx"
 #include "MFront/OverridableImplementation.hxx"
@@ -32,7 +32,6 @@ namespace mfront {
       const std::string& f) {
     auto dsl = MFrontBase::getDSL(f);
     dsl->analyseFile(f, {}, {});
-    dsl->endsInputFileProcessing();
     return dsl;
   }  // end of generateAbstractDSL
 
@@ -81,7 +80,9 @@ namespace mfront {
     return this->source;
   }  // end of getSourceFilePath
 
-  const std::map<std::string, std::vector<std::string>, std::less<>>&
+  const std::map<std::string,
+                 std::tuple<std::vector<std::string>, tfel::utilities::DataMap>,
+                 std::less<>>&
   OverridableImplementation::getExternalMFrontFiles() const {
     return this->dsl->getMaterialKnowledgeDescription()
         .getExternalMFrontFiles();
@@ -237,7 +238,7 @@ namespace mfront {
     }
     //
     madnex::write(g, impl);
-  }  // end of writeMadnexFile
+  }    // end of writeMadnexFile
 #endif /* MFRONT_HAVE_MADNEX */
 
   void write(const OverridableImplementation& i, const std::string& f) {
@@ -258,7 +259,7 @@ namespace mfront {
     static_cast<void>(i);
     tfel::raise("write: unsupported file extension '" + ext + "'");
 #endif /* MFRONT_HAVE_MADNEX */
-  }  // end of write
+  }    // end of write
 
   void write(const OverridableImplementation& i,
              const std::string& t,
