@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   06 mai 2008
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -30,13 +30,14 @@
 #include <io.h>
 #define F_OK 0 /* Test for existence.  */
 #ifndef S_ISREG
-#define S_ISREG(mode) (((mode) & S_IFMT) == S_IFREG)
+#define S_ISREG(mode) (((mode)&S_IFMT) == S_IFREG)
 #endif
 #endif
 
 #include "TFEL/Raise.hxx"
 #include "TFEL/Config/GetInstallPath.hxx"
 #include "TFEL/System/System.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/DSLUtilities.hxx"
 #include "MFront/MFrontUtilities.hxx"
 #include "MFront/MFrontHeader.hxx"
@@ -105,10 +106,6 @@ namespace mfront {
     } else {
       insert_if(l.cppflags, TFEL_PYTHON_INCLUDES);
     }
-    insert_if(l.cppflags,
-              "$(shell " + tfel_config + " --cppflags --compiler-flags)");
-    insert_if(l.include_directories,
-              "$(shell " + tfel_config + " --include-path)");
 #if !((defined _WIN32) && (defined _MSC_VER))
     insert_if(l.link_libraries, "m");
 #endif /* !((defined _WIN32) && (defined _MSC_VER)) */
@@ -333,10 +330,12 @@ namespace mfront {
             << "#include<cstdio>\n"
             << "#include<string>\n"
             << "#include<vector>\n"
+            << "#include<locale>\n"
             << "#include<cmath>\n"
             << "#include\"TFEL/Config/TFELTypes.hxx\"\n"
             << "#include\"TFEL/PhysicalConstants.hxx\"\n"
-            << "#include\"TFEL/Math/General/IEEE754.hxx\"\n\n";
+            << "#include\"TFEL/Math/General/IEEE754.hxx\"\n\n"
+            << "#include\"TFEL/Math/General/DerivativeType.hxx\"\n";
     if (useQuantities(mpd)) {
       srcFile << "#include\"TFEL/Math/qt.hxx\"\n"
               << "#include\"TFEL/Math/Quantity/qtIO.hxx\"\n";
@@ -377,6 +376,20 @@ namespace mfront {
               << "const double v"
               << "){\n";
       for (const auto& p : mpd.parameters) {
+        if (p.getExternalName() != p.name) {
+          srcFile << "if(strcmp(\"" << p.getExternalName() << "\",p) == 0){\n"
+                  << "python::" << hn << "::get" << hn << "()." << p.name
+                  << " = v;\n"
+                  << "return 1;\n"
+                  << "}\n";
+        }
+        if ((!p.symbolic_form.empty()) && (p.symbolic_form != p.name)) {
+          srcFile << "if(strcmp(\"" << p.symbolic_form << "\",p) == 0){\n"
+                  << "python::" << hn << "::get" << hn << "()." << p.name
+                  << " = v;\n"
+                  << "return 1;\n"
+                  << "}\n";
+        }
         srcFile << "if(strcmp(\"" << p.name << "\",p) == 0){\n"
                 << "python::" << hn << "::get" << hn << "()." << p.name
                 << " = v;\n"
