@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \brief 21 mai 2013
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -31,7 +31,6 @@
 #include "TFEL/Raise.hxx"
 #include "TFEL/Utilities/StringAlgorithms.hxx"
 #include "TFEL/System/System.hxx"
-#include "MFront/DSLUtilities.hxx"
 #include "MFront/SearchPathsHandler.hxx"
 
 namespace mfront {
@@ -242,7 +241,7 @@ namespace mfront {
         "SearchPathsHandler::addMadnexSearchPaths: "
         "madnex support is not enabled");
 #endif /* MFRONT_HAVE_MADNEX */
-  }  // end of addMadnexSearchPath
+  }    // end of addMadnexSearchPath
 
   void SearchPathsHandler::addSearchPaths(const std::string& p) {
     auto& msf = SearchPathsHandler::getSearchPathsHandler();
@@ -290,13 +289,14 @@ namespace mfront {
     return directories;
   }  // end of getSearchPaths
 
-  std::vector<SearchPathsHandler::Path> SearchPathsHandler::getRegistredPaths() {
+  std::vector<SearchPathsHandler::Path>
+  SearchPathsHandler::getRegistredPaths() {
     return SearchPathsHandler::getSearchPathsHandler().paths;
   }  // end of getRegistredPaths
 
-  void SearchPathsHandler::resetPaths(const std::vector<Path>& npaths){
+  void SearchPathsHandler::resetPaths(const std::vector<Path>& npaths) {
     SearchPathsHandler::getSearchPathsHandler().paths = npaths;
-  } // end of resetPaths
+  }  // end of resetPaths
 
   SearchPathsHandler::SearchPathsHandler() {
     const char* const p = ::getenv("MFRONT_INCLUDE_PATH");
@@ -315,4 +315,29 @@ namespace mfront {
     return msf;
   }  // end of getSearchPathsHandler
 
+#ifdef MFRONT_HAVE_MADNEX
+
+  std::tuple<std::string, std::string, std::string, std::string>
+  decomposeImplementationPathInMadnexFile(const std::string_view p) {
+    using result_type =
+        std::tuple<std::string, std::string, std::string, std::string>;
+    const auto details = tfel::utilities::tokenize(p, ':');
+    auto raise_if = [&p](const bool b) {
+      if (b) {
+        tfel::raise("decomposeImplementationPathInMadnexFile: invalid path '" +
+                    std::string{p} + "'");
+      }
+    };
+    raise_if((details.size() != 5) && (details.size() != 4));
+    if (details.size() == 4) {
+      return result_type{std::move(details[1]), std::move(details[2]), "",
+                         std::move(details[3])};
+    }
+    const auto mid = details[3] == "<none>" ? "" : details[3];
+    return result_type{std::move(details[1]), std::move(details[2]),
+                       std::move(mid), std::move(details[4])};
+  }  // end of decomposeImplementationPathInMadnexFile
+
+#endif /* MFRONT_HAVE_MADNEX */
+
 }  // end of namespace mfront
