@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \brief 10 juil. 2013
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -20,7 +20,8 @@
 #include "TFEL/Utilities/StringAlgorithms.hxx"
 #include "TFEL/Glossary/Glossary.hxx"
 #include "TFEL/Glossary/GlossaryEntry.hxx"
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/MFrontUtilities.hxx"
+#include "MFront/CodeGeneratorUtilities.hxx"
 #include "MFront/MFrontLogStream.hxx"
 #include "MFront/FileDescription.hxx"
 #include "MFront/UMATInterfaceBase.hxx"
@@ -1165,19 +1166,21 @@ namespace mfront {
                      "in mtest file generation");
       if (m.arraySize == 1u) {
         if (offset == 0) {
-          out << "mg.addMaterialProperty(\"" << m.name << "\",*(PROPS));\n";
+          out << "mg.addMaterialProperty(\"" << m.getExternalName()
+              << "\",*(PROPS));\n";
         } else {
-          out << "mg.addMaterialProperty(\"" << m.name << "\",*(PROPS+"
-              << offset << "));\n";
+          out << "mg.addMaterialProperty(\"" << m.getExternalName()
+              << "\",*(PROPS+" << offset << "));\n";
         }
         ++offset;
       } else {
         for (unsigned short s = 0; s != m.arraySize; ++s, ++offset) {
           if (offset == 0) {
-            out << "mg.addMaterialProperty(\"" << m.name << "[" << s
-                << "]\",*(PROPS));\n";
+            out << "mg.addMaterialProperty(\"" << m.getExternalName() << "["
+                << s << "]\",*(PROPS));\n";
           } else {
-            out << "mg.addMaterialProperty(\"" << m.name << "[" << s << "]\","
+            out << "mg.addMaterialProperty(\"" << m.getExternalName() << "["
+                << s << "]\","
                 << "*(PROPS+" << offset << "));\n";
           }
         }
