@@ -4,7 +4,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   17 Jan 2007
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -19,7 +19,7 @@
 #include "TFEL/Glossary/Glossary.hxx"
 #include "TFEL/Glossary/GlossaryEntry.hxx"
 #include "TFEL/Utilities/StringAlgorithms.hxx"
-#include "MFront/DSLUtilities.hxx"
+#include "MFront/MFrontUtilities.hxx"
 #include "MFront/SupportedTypes.hxx"
 #include "MFront/MFrontLogStream.hxx"
 #include "MFront/VariableDescription.hxx"
@@ -63,10 +63,6 @@ namespace mfront {
     return SupportedTypes::isScalarType(this->type);
   }  // end of isScalar
 
-  int VariableDescription::getVariableTypeIdentifier() const {
-    return SupportedTypes::getTypeIdentifier(this->type);
-  }  // end of getVariableTypeIdentifier
-
   void VariableDescription::setGlossaryName(const std::string& g) {
     using tfel::glossary::Glossary;
     auto throw_if = [](const bool b, const std::string& m) {
@@ -85,6 +81,18 @@ namespace mfront {
     this->glossaryName = glossary.getGlossaryEntry(g).getKey();
   }  // end of VariableDescription::setGlossaryName
 
+  void VariableDescription::resetGlossaryName(const std::string& g) {
+    using tfel::glossary::Glossary;
+    const auto& glossary = Glossary::getGlossary();
+    if (!glossary.contains(g)) {
+      tfel::raise("VariableDescription::resetGlossaryName: '" + g +
+                  "' is not a glossary name");
+    }
+    this->glossaryName.reset();
+    this->entryName.reset();
+    this->setGlossaryName(g);
+  }  // end of resetGlossaryName
+
   void VariableDescription::setEntryName(const std::string& e) {
     using tfel::glossary::Glossary;
     auto throw_if = [](const bool b, const std::string& m) {
@@ -103,6 +111,12 @@ namespace mfront {
     this->entryName = e;
   }  // end of VariableDescription::setEntryName
 
+  void VariableDescription::resetEntryName(const std::string& g) {
+    this->glossaryName.reset();
+    this->entryName.reset();
+    this->setEntryName(g);
+  }  // end of resetEntryName
+
   bool VariableDescription::hasGlossaryName() const {
     return this->glossaryName.has_value();
   }
