@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \brief  12 avril 2013
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -34,6 +34,7 @@
 
 #include "TFEL/Raise.hxx"
 #include "TFEL/Utilities/TerminalColors.hxx"
+#include "TFEL/Utilities/StringAlgorithms.hxx"
 #include "MFront/MFrontLogStream.hxx"
 
 #include "MTest/AnalyticalTest.hxx"
@@ -70,12 +71,21 @@ namespace mtest {
     // substitutions
     const auto pe = s.end();
     for (auto& token : this->tokens) {
-      auto p = s.find(token.value);
-      if (p != pe) {
-        token.value = p->second;
-        if (((p->second.front() == '\'') && (p->second.back() == '\'')) ||
-            ((p->second.front() == '"') && (p->second.back() == '"'))) {
-          token.flag = tfel::utilities::Token::String;
+      if (token.flag == tfel::utilities::Token::String) {
+        auto delim = token.value.at(0);
+        auto contents = token.value.substr(1, token.value.size() - 2);
+        for (const auto& [k, v] : s) {
+          contents = tfel::utilities::replace_all(contents, k, v);
+        }
+        token.value = delim + contents + delim;
+      } else {
+        auto p = s.find(token.value);
+        if (p != pe) {
+          token.value = p->second;
+          if (((p->second.front() == '\'') && (p->second.back() == '\'')) ||
+              ((p->second.front() == '"') && (p->second.back() == '"'))) {
+            token.flag = tfel::utilities::Token::String;
+          }
         }
       }
     }
