@@ -3,7 +3,7 @@
  * \brief
  * \author Thomas Helfer
  * \brief 07 avril 2013
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -316,6 +316,8 @@ namespace mtest {
         return MechanicalBehaviourBase::FINITESTRAINKINEMATIC_F_CAUCHY;
       case 4:
         return MechanicalBehaviourBase::FINITESTRAINKINEMATIC_ETO_PK1;
+      default:
+        break;
     }
     tfel::raise(
         "StandardBehaviourBase::getBehaviourKinematic: "
