@@ -4,7 +4,7 @@
  *
  * \author Thomas Helfer
  * \date   02 oct 2007
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -252,6 +252,8 @@ namespace tfel::math {
         return std::make_shared<PowerFunction<15>>(e);
       case 16:
         return std::make_shared<PowerFunction<16>>(e);
+      default:
+        break;
     }
     return std::make_shared<GeneralPowerFunction>(e, n);
   }  // end of makePowerFunctionExpression
