@@ -4,7 +4,7 @@
  * \brief
  * \author Thomas Helfer
  * \date   20 Nov 2006
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -294,9 +294,7 @@ namespace tfel::utilities {
     using return_type = bool;
     // default implementation
     template <typename T1, typename T2>
-    static bool apply(const T1&, const T2&)
-      requires(!std::is_same_v<T1, T2>)
-    {
+    static bool apply(const T1&, const T2&) requires(!std::is_same_v<T1, T2>) {
       return false;
     }  // end of apply
     static bool apply(const std::string& x1, const std::string& x2) {
@@ -337,7 +335,7 @@ namespace tfel::utilities {
     static bool apply(const double v1, const double v2) {
       return tfel::math::ieee754::fpclassify(v1 - v2) == FP_ZERO;
     }  // end of apply
-  };  // end of struct DataComparator
+  };   // end of struct DataComparator
 
   bool operator==(const Data& lhs, const Data& rhs) {
     if (&lhs == &rhs) {
@@ -435,6 +433,16 @@ namespace tfel::utilities {
     return r;
   }
 
+  DataMap remove(const DataMap& m, const std::vector<std::string>& names) {
+    auto r = DataMap();
+    for (const auto& [k, v] : m) {
+      if (std::find(names.begin(), names.end(), k) == names.end()) {
+        r.insert({k, v});
+      }
+    }
+    return r;
+  }
+
   DataMap merge(const DataMap& m1, const DataMap& m2, const bool b) {
     auto r = m1;
     if (b) {
@@ -450,4 +458,43 @@ namespace tfel::utilities {
     return r;
   }
 
+  void check_keys(const DataMap& d, const std::vector<std::string>& keys) {
+    auto faults = std::vector<std::string>{};
+    for (const auto& de : d) {
+      if (std::find(keys.begin(), keys.end(), de.first) == keys.end()) {
+        faults.push_back(de.first);
+      }
+    }
+    if (faults.empty()) {
+      return;
+    }
+    auto msg = [&faults] {
+      if (faults.size() == 1) {
+        return "check_keys: key '" + faults[0] + "' is not allowed";
+      }
+      auto r = std::string{"check_keys: keys"};
+      const auto pe = faults.end();
+      for (auto p = faults.begin(); p != pe; ++p) {
+        if (std::next(p) == pe) {
+          r += " and '" + *p + "'";
+        } else {
+          if (p == faults.begin()) {
+            r += " '" + *p + "'";
+          } else {
+            r += ", '" + *p + "'";
+          }
+        }
+      }
+      r += " are not allowed";
+      return r;
+    }();
+    if (!keys.empty()) {
+      msg += ". The following keys are allowed:";
+      for (const auto& k : keys) {
+        msg += "\n- " + k;
+      }
+    }
+    raise(msg);
+  }  // end of check_keys
+
 }  // end of namespace tfel::utilities
