@@ -2,7 +2,7 @@
  * \file   tests/MetaProgramming/typelist2.cxx
  * \brief
  * \author Thomas Helfer
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -49,8 +49,7 @@ class generic_container : public generic_container_<T, holder> {
  public:
   template <unsigned int N>
   typename tfel::meta::TLFindNthElt<T, N>::type get() const
-    requires(N < tfel::meta::TLSize<T>::value)
-  {
+      requires(N < tfel::meta::TLSize<T>::value) {
     return static_cast<
                const holder<typename tfel::meta::TLFindNthElt<T, N>::type>*>(
                this)
@@ -58,9 +57,8 @@ class generic_container : public generic_container_<T, holder> {
   }
 
   template <unsigned int N>
-  void set(const typename tfel::meta::TLFindNthElt<T, N>::type& src)
-    requires(N < tfel::meta::TLSize<T>::value)
-  {
+  void set(const typename tfel::meta::TLFindNthElt<T, N>::type& src) requires(
+      N < tfel::meta::TLSize<T>::value) {
     static_cast<holder<typename tfel::meta::TLFindNthElt<T, N>::type>*>(this)
         ->set(src);
   }
