@@ -3,7 +3,7 @@
  * \brief  Class to manage tfel unit tests.
  * \author Thomas Helfer
  * \date   26 jan 2008
- * \copyright Copyright (C) 2006-2018 CEA/DEN, EDF R&D. All rights
+ * \copyright Copyright (C) 2006-2025 CEA/DEN, EDF R&D. All rights
  * reserved.
  * This project is publicly released under either the GNU GPL Licence with
  * linking exception or the CECILL-A licence. A copy of thoses licences are
@@ -623,7 +623,13 @@ namespace tfel::check {
     this->treatCharAsString(true);
     this->mergeStrings(false);
     // open the file
-    this->openFile(this->file);
+    try {
+      this->openFile(this->file);
+    } catch (std::exception& e) {
+      this->throwRuntimeError(
+          "TestLauncher::analyseInputFile",
+          "error while parsing '" + this->file + "', " + std::string{e.what()});
+    }
     // strip any C/C++ comments
     this->stripComments();
     // applying substitutions
@@ -637,9 +643,14 @@ namespace tfel::check {
     while (this->current != this->end()) {
       const auto p = this->callBacks.find(this->current->value);
       if (p == this->callBacks.end()) {
-        this->throwRuntimeError(
-            "TestLauncher::analyseInputFile",
-            "unknown keyword '" + this->current->value + "'");
+        auto msg = "unknown keyword '" + this->current->value + "'";
+        if (!this->callBacks.empty()) {
+          msg += ". The following keywords are available:";
+          for (const auto& cb : this->callBacks) {
+            msg += "\n- " + cb.first;
+          }
+        }
+        this->throwRuntimeError("TestLauncher::analyseInputFile", msg);
       }
       ++(this->current);
       (this->*(p->second))();
@@ -747,8 +758,14 @@ namespace tfel::check {
       const auto output_file = this->testname + "-" + step + ".out";
       const auto success = this->execute(c, output_file, step);
       this->glog.addSimpleTestResult("** " + step + " " + c.command, success);
-      if ((!success) && (this->comparisons.empty())) {
-        gsuccess = false;
+      if (!success) {
+        if (!configuration.discard_commands_failure) {
+          gsuccess = false;
+        } else {
+          if (this->comparisons.empty()) {
+            gsuccess = false;
+          }
+        }
       }
       ++i;
     }
